package se.pmws1213.diaballik.controller;

import java.beans.PropertyChangeEvent;

import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.swt.events.MouseEvent;
import org.eclipse.swt.events.MouseListener;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Label;

import se.pmws1213.Ball;
import se.pmws1213.DiaballikGame;
import se.pmws1213.Field;
import se.pmws1213.Holder;
import se.pmws1213.Move;
import se.pmws1213.Pass;
import se.pmws1213.diaballik.Util;
import se.pmws1213.diaballik.gui.DiaballikMainScreen;

public class FieldController extends AbstractController
{

	private Field field;
	private Label label;
	private Button skipButton;
	private DiaballikMainScreen mainScreen;

	public FieldController(Field field, Label label, DiaballikMainScreen mainScreen)
	{
		this.field = field;
		this.label = label;
		this.mainScreen = mainScreen;
		this.skipButton = mainScreen.getBtnSkip();
	}

	public void start()
	{
		super.start();
	}

	@Override
	public void propertyChange(PropertyChangeEvent evt)
	{
		Display.getDefault().asyncExec(new Runnable() {

			@Override
			public void run()
			{
				Image img = Util.getImage(field);
				label.setImage(img);
			}
		});
	}

	@Override
	public void refreshUI()
	{
		Image img = Util.getImage(field);
		label.setImage(img);
	}

	@Override
	public void registerListeners()
	{
		label.addMouseListener(new MouseListener() {

			@Override
			public void mouseUp(MouseEvent arg0)
			{
				DiaballikGame game = field.getDiaballikGame();
				Field selectedField = game.getSelectedField();
				if(selectedField != null)
				{
					Holder holder = selectedField.getHolder();
					if(holder != null)
					{
						Ball ball = holder.getBall();
						if(ball != null)
						{
							boolean pass = ball.pass(field.getHolder());
							if(!pass)
							{
								MessageDialog.openInformation(null, "Invalid pass!", "Invalid pass! Select your ball and pass it to a valid holder!");
							}
						}
						else
						{
							boolean move = holder.move(field);
							if(!move)
							{
								MessageDialog.openInformation(null, "Invalid move!", "Invalid move! Select one of your holders and move it to a valid empty field!");
							}
						}
						
						if(game.checkEnd())
						{
							return;
						}
						
						if (game.getCurrentPlayer().getActions().size() == 2)
						{
							skipButton.setEnabled(true);
						}
						else if (game.getCurrentPlayer().getActions().isEmpty())
						{
							game.getCurrentPlayer().removeAllFromActions();
							game.setCurrentPlayer(game.getCurrentPlayer().getNext());
							game.getCurrentPlayer().withActions(new Move()).withActions(new Move()).withActions(new Pass());
							skipButton.setEnabled(false);
						}
					}
					Util.findLabelForField(mainScreen, selectedField).setEnabled(true);
					game.setSelectedField(null);
				}
				else
				{
					Holder sourceHolder = field.getHolder();
					if(sourceHolder != null && sourceHolder.getPlayer() == game.getCurrentPlayer())
					{
						label.setEnabled(false);
						game.setSelectedField(field);
					}
					else
					{
						MessageDialog.openInformation(null, "Invalid field!", "Select your ball or one of your holders!");
					}
				}
			}

			@Override
			public void mouseDown(MouseEvent arg0) {}

			@Override
			public void mouseDoubleClick(MouseEvent arg0) {}
		});

		listenTo(Field.PROPERTY_HOLDER, field);
	}
}
