package se.pmws1213.diaballik.gui;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.FocusAdapter;
import org.eclipse.swt.events.FocusEvent;
import org.eclipse.swt.layout.FillLayout;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;
import org.eclipse.wb.swt.SWTResourceManager;

import se.pmws1213.diaballik.Util;

public class DiaballikStartScreen
{
   private class RestoreContentFocusAdapter extends FocusAdapter
   {
      
      private final String toRestore;

      public RestoreContentFocusAdapter(String toRestore)
      {
         this.toRestore = toRestore;
      }
      
      @Override
      public void focusGained(FocusEvent e)
      {
         Text text = getText(e);
         if(toRestore.equals(text.getText()))
         {
            text.setText("");
         }
      }
      
      @Override
      public void focusLost(FocusEvent e)
      {
         Text text = getText(e);
         if(text.getText() == null || text.getText().trim().length() == 0)
         {
            text.setText(toRestore);
         }
      }

      private Text getText(FocusEvent e)
      {
         Text t = (Text)e.widget;
         return t;
      }
   }

	protected Shell startGameShell;
	private Text txtPlayer1;
	private Text txtPlayer2;
	private Composite buttonPane;
	private Button btnStart;
	private Button btnExit;
	private Label lblDiaballik;
	public Label getLblDiaballik() {
		return lblDiaballik;
	}
	private Label lblRedPlayerImg;
	private Label lblGreenPLayerImg;

	/**
	 * Launch the application.
	 * @param args
	 */
	public static void main(String[] args) {
		try {
			DiaballikMainScreen window = new DiaballikMainScreen();
			window.open();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	/**
	 * Open the window.
	 */
	public void open() {
		Display display = Display.getDefault();
		createContents();
		Util.centerShell(startGameShell);
		startGameShell.open();
		startGameShell.layout();
		
		while (!startGameShell.isDisposed()) {
			if (!display.readAndDispatch()) {
				display.sleep();
			}
		}
	}
	
	/**
	 * Create contents of the window.
	 * @wbp.parser.entryPoint
	 */
	public void createContents()
	{
		startGameShell = new Shell();
		startGameShell.setSize(451, 379);
		startGameShell.setText("Diaballik Login");
		startGameShell.setLayout(new FillLayout(SWT.VERTICAL));
		
		lblDiaballik = new Label(startGameShell, SWT.CENTER);
		lblDiaballik.setAlignment(SWT.CENTER);
		lblDiaballik.setFont(SWTResourceManager.getFont("Rockwell", 17, SWT.BOLD));
		lblDiaballik.setText("Diaballik");
		
		Composite playerPane = new Composite(startGameShell, SWT.NONE);
		GridLayout gl_playerPane = new GridLayout(1, false);
		playerPane.setLayout(gl_playerPane);
		
		Composite playerNamesPane = new Composite(playerPane, SWT.NONE);
		playerNamesPane.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, true, 1, 1));
		GridLayout gl_playerNamesPane = new GridLayout(2, false);
		gl_playerNamesPane.verticalSpacing = 10;
		playerNamesPane.setLayout(gl_playerNamesPane);
		
		lblRedPlayerImg = new Label(playerNamesPane, SWT.NONE);
		lblRedPlayerImg.setImage(SWTResourceManager.getImage(DiaballikStartScreen.class, "/img/redPlayer.png"));
		lblRedPlayerImg.setLayoutData(new GridData(SWT.RIGHT, SWT.CENTER, false, false, 1, 1));
		
		txtPlayer1 = new Text(playerNamesPane, SWT.BORDER | SWT.CENTER);
		txtPlayer1.setForeground(SWTResourceManager.getColor(SWT.COLOR_WIDGET_BORDER));
		txtPlayer1.setFont(SWTResourceManager.getFont("Segoe UI", 18, SWT.NORMAL));
		txtPlayer1.setText("Player 1");
		txtPlayer1.addFocusListener(new RestoreContentFocusAdapter("Player 1"));
		GridData gd_txtPlayer1 = new GridData(SWT.FILL, SWT.FILL, true, false, 1, 1);
		gd_txtPlayer1.widthHint = 334;
		txtPlayer1.setLayoutData(gd_txtPlayer1);
		
		lblGreenPLayerImg = new Label(playerNamesPane, SWT.NONE);
		lblGreenPLayerImg.setImage(SWTResourceManager.getImage(DiaballikStartScreen.class, "/img/greenPlayer.png"));
		lblGreenPLayerImg.setLayoutData(new GridData(SWT.RIGHT, SWT.CENTER, false, false, 1, 1));
		
		txtPlayer2 = new Text(playerNamesPane, SWT.BORDER | SWT.CENTER);
		txtPlayer2.setForeground(SWTResourceManager.getColor(SWT.COLOR_WIDGET_BORDER));
		txtPlayer2.setFont(SWTResourceManager.getFont("Segoe UI", 18, SWT.NORMAL));
		txtPlayer2.setText("Player 2");
		txtPlayer2.addFocusListener(new RestoreContentFocusAdapter("Player 2"));
		txtPlayer2.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, false, 1, 1));
		
		buttonPane = new Composite(startGameShell, SWT.NONE);
		buttonPane.setLayout(null);
		
		btnStart = new Button(buttonPane, SWT.NONE);
		btnStart.setBounds(10, 50, 74, 31);
		btnStart.setText("Start Game");
		
		btnExit = new Button(buttonPane, SWT.NONE);
		btnExit.setBounds(361, 50, 64, 31);
		btnExit.setText("Exit Game");

	}

	public Button getStartButton() {
		return btnStart;
	}
	public Button getExitButton() {
		return btnExit;
	}
	public Text getPlayer1Text() {
		return txtPlayer1;
	}
	public Text getPlayer2Text() {
		return txtPlayer2;
	}
	public Shell getStartGameShell() {
		return startGameShell;
	}
	
	
}
